From f9c8a993582944c7793e3e360697b2d3f159f53c Mon Sep 17 00:00:00 2001
From: Latif Khalifa
Date: Thu, 5 Jun 2014 20:18:54 +0200
Subject: [PATCH] Branding: Singularity -> Replex (part 2)
---
htdocs/batch_process.php | 2 +-
htdocs/download.php | 2 +-
htdocs/index.php | 4 ++--
htdocs/lib/CrashReport.php | 8 ++++----
htdocs/lib/Layout.php | 2 +-
htdocs/lib/Option.php | 2 +-
htdocs/lib/ReportParser.php | 2 +-
htdocs/lib/SearchFilter.php | 4 ++--
htdocs/lib/Session.php | 4 ++--
htdocs/lib/http.php | 2 +-
htdocs/report_detail.php | 2 +-
htdocs/sync_builds.php | 2 +-
12 files changed, 18 insertions(+), 18 deletions(-)
mode change 100755 => 100644 htdocs/batch_process.php
diff --git a/htdocs/batch_process.php b/htdocs/batch_process.php
old mode 100755
new mode 100644
index 54dd1d5..0016c2c
--- a/htdocs/batch_process.php
+++ b/htdocs/batch_process.php
@@ -75,7 +75,7 @@ if ($nr)
{
Memc::flush();
$rp = $nr != 1 ? "reports" : "report";
- //IRCNotify::send("#SingularityViewer", "[CrashProcessor] $nr new $rp. http://crash.singularityviewer.org/");
+ IRCNotify::send("#replex", "[CrashProcessor] $nr new $rp. http://crash.replex.org/");
}
Session::GC();
diff --git a/htdocs/download.php b/htdocs/download.php
index f7baade..6c03c9e 100644
--- a/htdocs/download.php
+++ b/htdocs/download.php
@@ -15,4 +15,4 @@ if (!$miniDump || !($miniDump->getData()))
}
header("Content-Type: application/octet-stream");
-http::sendDownload("singularity" . ((int)$_GET["report_id"]) . ".dmp", $miniDump->getData());
\ No newline at end of file
+http::sendDownload("replex" . ((int)$_GET["report_id"]) . ".dmp", $miniDump->getData());
\ No newline at end of file
diff --git a/htdocs/index.php b/htdocs/index.php
index cca8b53..b7fccb1 100644
--- a/htdocs/index.php
+++ b/htdocs/index.php
@@ -11,12 +11,12 @@ if (!$S->isAnonymous() && $S->user->isAllowed())
Layout::header();
?>
-This application is used for analyzing crash reports and statitstics for the Singularity
+
This application is used for analyzing crash reports and statitstics for the Replex
Viewer project.
Access to this tool is granted to the members of the development team.
The main goal is to identify the most common problems and improve the expierience
-for the users of Singularity Viewer.
+for the users of Replex Viewer.
source_file = str_replace("\\", "/", $f->source_file);
- if (stristr($f->module, "singularity") !== false)
+ if (stristr($f->module, "replex") !== false)
{
- $f->module = "singularity";
+ $f->module = "replex";
}
else if (stristr($f->module, "llcommon") !== false)
{
@@ -432,7 +432,7 @@ class CrashReport
self::$builds_map = self::getBuildsMap();
}
- if (!self::$builds_map[$chan]) $chan = "SingularityAlpha";
+ if (!self::$builds_map[$chan]) $chan = "ReplexAlpha";
if (!self::$builds_map[$chan][$version]) return "master";
diff --git a/htdocs/lib/Layout.php b/htdocs/lib/Layout.php
index 77fb39f..da54900 100644
--- a/htdocs/lib/Layout.php
+++ b/htdocs/lib/Layout.php
@@ -126,7 +126,7 @@ class Layout
-
+
Replex Viewer - Automated Crash Report Processing System
diff --git a/htdocs/lib/Option.php b/htdocs/lib/Option.php
index 1ca35f6..865a129 100644
--- a/htdocs/lib/Option.php
+++ b/htdocs/lib/Option.php
@@ -4,7 +4,7 @@
* Simple key-value store for various options
*
* Description
-* @package Singularity Crash Processor
+* @package Replex Crash Processor
* @author Latif Khalifa
* @copyright Copyright © 2012, Latif Khalifa
*
diff --git a/htdocs/lib/ReportParser.php b/htdocs/lib/ReportParser.php
index 3588cfb..8138ae5 100644
--- a/htdocs/lib/ReportParser.php
+++ b/htdocs/lib/ReportParser.php
@@ -3,7 +3,7 @@
* Parses incoming raw crash reports
*
* Description
-* @package Singularity Crash Processor
+* @package Replex Crash Processor
* @author Latif Khalifa
* @copyright Copyright © 2012, Latif Khalifa
*
diff --git a/htdocs/lib/SearchFilter.php b/htdocs/lib/SearchFilter.php
index 74d46c4..35b5cc0 100644
--- a/htdocs/lib/SearchFilter.php
+++ b/htdocs/lib/SearchFilter.php
@@ -205,8 +205,8 @@ class SearchFilter
Channel
chan ? 'checked="checked"' : '' ?>/>All
- chan == "Singularity" ? 'checked="checked"' : '' ?>/>Singularity
- chan == "SingularityAlpha" ? 'checked="checked"' : '' ?>/>SingularityAlpha
+ chan == "Replex" ? 'checked="checked"' : '' ?>/>Replex
+ chan == "ReplexAlpha" ? 'checked="checked"' : '' ?>/>ReplexAlpha
diff --git a/htdocs/lib/http.php b/htdocs/lib/http.php
index dd02d7e..4bf22b6 100644
--- a/htdocs/lib/http.php
+++ b/htdocs/lib/http.php
@@ -4,7 +4,7 @@
* Common http operations such as redirects, etc.
*
* Description
-* @package Singularity Crash Processor
+* @package Replex Crash Processor
* @author Latif Khalifa
* @copyright Copyright © 2012, Latif Khalifa
*
diff --git a/htdocs/report_detail.php b/htdocs/report_detail.php
index 3df25ed..82215d2 100644
--- a/htdocs/report_detail.php
+++ b/htdocs/report_detail.php
@@ -131,7 +131,7 @@ $(function() {
Minidump
- Download
+ Download
diff --git a/htdocs/sync_builds.php b/htdocs/sync_builds.php
index 4a92aea..0c52069 100644
--- a/htdocs/sync_builds.php
+++ b/htdocs/sync_builds.php
@@ -11,7 +11,7 @@ if (PHP_SAPI != "cli")
header("Content-Type: text/plain");
}
-if (!$remote_map = json_decode(file_get_contents("http://alpha.singularityviewer.org/alpha/builds_map.php"))) return;
+if (!$remote_map = json_decode(file_get_contents("http://files.streamgrid.net/replex/builds_map.php"))) return;
$existing = CrashReport::getBuildsMap();
diff --git a/htdocs/lib/Session.php b/htdocs/lib/Session.php
index 56ca5b8..2beba6b 100644
--- a/htdocs/lib/Session.php
+++ b/htdocs/lib/Session.php
@@ -4,7 +4,7 @@
* This class handles sessions
*
* Description
* @package Singularity Crash Processor
* @author Latif Khalifa
* @copyright Copyright © 2012, Latif Khalifa
*
@@ -47,7 +47,7 @@ class Session
$this->timeout = 604800; // 7 days
$this->authenticated = false;
$this->validsession = false;
- $this->cookie = "singularity_sid";
+ $this->cookie = "replex_sid";
$this->user = new User;
$this->persist = new stdClass;
register_shutdown_function(array(&$this, 'shutdown'));
@@ -4,7 +4,7 @@
*
* Description
-* @package Singularity Crash Processor
+* @package Replex Crash Processor
* @author Latif Khalifa
* @copyright Copyright © 2012, Latif Khalifa